package com.diagbot.util;

import com.google.common.collect.Lists;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author zhoutg
 * @Description: 正则匹配工具类
 * @date 2020-12-16 11:28
 */
public class RegexUtil {

    /**
     * 判断字符串是否数值(正), ex: 10|20.1|0.83|10.|.99
     *
     * @param str
     * @return
     */
    public static boolean isNumbers(String str) {
        String regex = "[0-9]+|([0-9]+\\.)+[0-9]*|[0-9]*(\\.[0-9]+)+";
        return str.matches(regex);
    }

    /**
     * 是否有符合的数据(公共方法)
     *
     * @param content 文本内容
     * @param regex   表达式
     * @return
     */
    public static Boolean getRegexRes(String content, String regex) {
        // 是否有符合的数据
        try {
            if (StringUtil.isBlank(content) || StringUtil.isBlank(regex)) {
                return false;
            }
            Pattern pattern = Pattern.compile(regex, Pattern.CASE_INSENSITIVE);
            Matcher matcher = pattern.matcher(content);
            if (matcher.find()) {
                return true;
            }
        } catch (Exception e) {
            return false;
        }
        return false;
    }

    /**
     * 根据正则获取指定分组数据
     *
     * @param content  文本内容
     * @param regex    表达式
     * @param groupNum 获取第几个内容
     * @return
     */
    public static String getRegexData(String content, String regex, Integer groupNum) {
        // 获取符合的数据
        try {
            if (StringUtil.isBlank(content)) {
                return "";
            }
            Pattern pattern = Pattern.compile(regex, Pattern.CASE_INSENSITIVE);
            Matcher matcher = pattern.matcher(content);
            if (matcher.find() && matcher.groupCount() >= groupNum) {
                return matcher.group(groupNum);
            } else {
                return "";
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return "";
    }

    /**
     * 根据正则获取指定所有分组数据
     *
     * @param content
     * @param regex
     * @return
     */
    public static List<String> getRegexData(String content, String regex) {
        List<String> list = Lists.newArrayList();
        try {
            if (StringUtil.isBlank(content)) {
                return list;
            }
            Pattern pattern = Pattern.compile(regex, Pattern.CASE_INSENSITIVE);
            Matcher matcher = pattern.matcher(content);
            if (matcher.find()) {
                for (int i = 1; i <= matcher.groupCount(); i++) {
                    list.add(matcher.group(i));
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return list;
    }

    /**
     * 测试
     *
     * @param args
     */
    public static void main(String[] args) {
        String regex1 = "(血小板计数)\\s*(\\d+(\\.\\d+)?)";
        // System.out.println(getRegexData("血小板计数  30.3", regex1, 2));
        System.out.println(getRegexData("血小板计数  30.3", regex1));
    }
}
